.. Axelrod documentation master file, created by
   sphinx-quickstart on Sat Mar  7 07:05:57 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the documentation for an implementation of Axelrod's tournament in Python
====================================================================================

This project is both:

* A python library that reproduces Axelrod's tournament.
* A github experiment allowing anyone to contribute a strategy.


Contents:

.. toctree::
   :maxdepth: 2

   background
   usage
   overview_of_strategies
   index_of_strategies
   contributing


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

